{% extends "inc/base.j2" %}
{% block content %}

<div class="page-header">
  <h2>update state value / {{ key }}</h2>
</div>

<form method="post">
  <sl-textarea name="value" rows="10" cols="30" value="{{ value }}"></sl-textarea>
  <sl-divider></sl-divider>
  <sl-button type="submit" variant="primary">update</sl-button>
</form>



{% endblock %}