@charset "UTF-8";

:not(:defined) {
    visibility: hidden;
}

body {
    margin: 0;
    padding: 10px 20px;
    flex-direction: column;
    align-items: center;
    box-sizing: border-box;
    font-family: var(--sl-font-sans);
    font-size: var(--sl-font-size-medium);
    line-height: var(--sl-line-height-normal);
}

header,
footer,
main {
    width: 100%;

}

.inline {
    display: flex;
    align-items: center;
    gap: 0.3rem;
}

table {
    width: 100%;
    border-collapse: collapse;
}

table th,
table td {
    padding: 0.75rem;
    border-bottom: 1px solid var(--sl-color-neutral-200);
    text-align: left;
}

table th {
    background-color: var(--sl-color-neutral-100);
    color: var(--sl-color-neutral-700);
}

sl-menu-item a {
    display: block;
    width: 100%;
    color: inherit;
    text-decoration: none;
}

.page-header {
    display: flex;
    align-items: center;
    gap: 1rem;
    height: 2rem;
    padding-bottom: 2rem;
}

.sortable thead th:not(.no-sort) {
    cursor: pointer;
}

.sortable thead th:not(.no-sort)::after,
.sortable thead th:not(.no-sort)::before {
    transition: color 0.1s ease-in-out;
    font-size: 1.2em;
    color: transparent;
}

.sortable thead th:not(.no-sort)::after {
    margin-left: 3px;
    content: "▸";
}

.sortable thead th:not(.no-sort):hover::after {
    color: inherit;
}

.sortable thead th:not(.no-sort)[aria-sort=descending]::after {
    color: inherit;
    content: "▾";
}

.sortable thead th:not(.no-sort)[aria-sort=ascending]::after {
    color: inherit;
    content: "▴";
}

.sortable thead th:not(.no-sort).indicator-left::after {
    content: "";
}

.sortable thead th:not(.no-sort).indicator-left::before {
    margin-right: 3px;
    content: "▸";
}

.sortable thead th:not(.no-sort).indicator-left:hover::before {
    color: inherit;
}

.sortable thead th:not(.no-sort).indicator-left[aria-sort=descending]::before {
    color: inherit;
    content: "▾";
}

.sortable thead th:not(.no-sort).indicator-left[aria-sort=ascending]::before {
    color: inherit;
    content: "▴";
}