{% extends "inc/base.j2" %}
{% block content %}

<div class="page-header">
  <h2>update dynamic configs from toml</h2>
</div>


<form method="post">
  <sl-textarea name="value" rows="10" cols="30" value="{{ toml_str }}"></sl-textarea>
  <sl-divider></sl-divider>
  <sl-button type="submit" variant="primary">update</sl-button>
</form>

{% endblock %}